@@ -31,7 +31,6 @@
 
 #include "e-day-view-time-item.h"
 #include "calendar-config.h"
-#include <widgets/e-timezone-dialog/e-timezone-dialog.h>
 
 /* The spacing between items in the time column. GRID_X_PAD is the space down
  * either side of the column, i.e. outside the main horizontal grid lines.
@@ -500,9 +499,7 @@ edvti_draw_zone (GnomeCanvasItem *canvas_item,
 			cairo_restore (cr);
 
 			if (show_midnight_date) {
-				strcpy (buffer, midnight_day);
-				strcat (buffer, " ");
-				strcat (buffer, midnight_month);
+				g_snprintf (buffer, sizeof (buffer), "%s %s", midnight_day, midnight_month);
 			} else if (e_cal_model_get_use_24_hour_format (model)) {
 				g_snprintf (
 					buffer, sizeof (buffer), "%i:%02i",
@@ -540,7 +537,7 @@ edvti_draw_zone (GnomeCanvasItem *canvas_item,
 				cairo_save (cr);
 				gdk_cairo_set_source_color (cr, &dark);
 				if (show_midnight_date)
-					strcpy (buffer, midnight_day);
+					g_snprintf (buffer, sizeof (buffer), "%s", midnight_day);
 				else
 					g_snprintf (
 						buffer, sizeof (buffer), "%i",
@@ -590,10 +587,10 @@ edvti_draw_zone (GnomeCanvasItem *canvas_item,
 				/* In 12-hour format we display 'am' or 'pm'
 				 * instead of '00'. */
 				if (show_midnight_date)
-					strcpy (buffer, midnight_month);
+					g_snprintf (buffer, sizeof (buffer), "%s", midnight_month);
 				else if (minute == 0
 				    && !e_cal_model_get_use_24_hour_format (model)) {
-					strcpy (buffer, suffix);
+					g_snprintf (buffer, sizeof (buffer), "%s", suffix);
 				} else {
 					g_snprintf (
 						buffer, sizeof (buffer),
@@ -910,6 +907,9 @@ e_day_view_time_item_on_button_press (EDayViewTimeItem *time_item,
 	GdkWindow *window;
 	EDayView *day_view;
 	GnomeCanvas *canvas;
+	GdkGrabStatus grab_status;
+	GdkDevice *event_device;
+	guint32 event_time;
 	gint row;
 
 	day_view = e_day_view_time_item_get_day_view (time_item);
@@ -929,10 +929,20 @@ e_day_view_time_item_on_button_press (EDayViewTimeItem *time_item,
 
 	window = gtk_layout_get_bin_window (GTK_LAYOUT (canvas));
 
-	if (gdk_pointer_grab (window, FALSE,
-			      GDK_POINTER_MOTION_MASK
-			      | GDK_BUTTON_RELEASE_MASK,
-			      NULL, NULL, event->button.time) == 0) {
+	event_device = gdk_event_get_device (event);
+	event_time = gdk_event_get_time (event);
+
+	grab_status = gdk_device_grab (
+		event_device,
+		window,
+		GDK_OWNERSHIP_NONE,
+		FALSE,
+		GDK_POINTER_MOTION_MASK |
+		GDK_BUTTON_RELEASE_MASK,
+		NULL,
+		event_time);
+
+	if (grab_status == GDK_GRAB_SUCCESS) {
 		e_day_view_start_selection (day_view, -1, row);
 		time_item->priv->dragging_selection = TRUE;
 	}
@@ -948,7 +958,13 @@ e_day_view_time_item_on_button_release (EDayViewTimeItem *time_item,
 	g_return_if_fail (day_view != NULL);
 
 	if (time_item->priv->dragging_selection) {
-		gdk_pointer_ungrab (event->button.time);
+		GdkDevice *event_device;
+		guint32 event_time;
+
+		event_device = gdk_event_get_device (event);
+		event_time = gdk_event_get_time (event);
+		gdk_device_ungrab (event_device, event_time);
+
 		e_day_view_finish_selection (day_view);
 		e_day_view_stop_auto_scroll (day_view);
 	}
