@@ -24,6 +24,7 @@
 #endif
 
 #include "e-attachment-store.h"
+#include "e-icon-factory.h"
 
 #include <errno.h>
 #include <glib/gi18n.h>
@@ -281,6 +282,13 @@ e_attachment_store_remove_all (EAttachmentStore *store)
 	if (!g_hash_table_size (store->priv->attachment_index))
 		return;
 
+	/* Clear the list store before cancelling EAttachment load/save
+	 * operations.  This will invalidate the EAttachment's tree row
+	 * reference so it won't try to update the row's icon column in
+	 * response to the cancellation.  That can create problems when
+	 * the list store is being disposed. */
+	gtk_list_store_clear (GTK_LIST_STORE (store));
+
 	g_object_freeze_notify (G_OBJECT (store));
 
 	list = e_attachment_store_get_attachments (store);
@@ -294,8 +302,6 @@ e_attachment_store_remove_all (EAttachmentStore *store)
 	g_list_foreach (list, (GFunc) g_object_unref, NULL);
 	g_list_free (list);
 
-	gtk_list_store_clear (GTK_LIST_STORE (store));
-
 	g_object_notify (G_OBJECT (store), "num-attachments");
 	g_object_notify (G_OBJECT (store), "total-size");
 	g_object_thaw_notify (G_OBJECT (store));
@@ -410,6 +416,31 @@ e_attachment_store_get_total_size (EAttachmentStore *store)
 	return total_size;
 }
 
+static void
+update_preview_cb (GtkFileChooser *file_chooser,
+                   gpointer data)
+{
+	GtkWidget *preview;
+	gchar *filename = NULL;
+	GdkPixbuf *pixbuf;
+
+	gtk_file_chooser_set_preview_widget_active (file_chooser, FALSE);
+	gtk_image_clear (GTK_IMAGE (data));
+	preview = GTK_WIDGET (data);
+	filename = gtk_file_chooser_get_preview_filename (file_chooser);
+	if (filename == NULL)
+		return;
+
+	pixbuf = gdk_pixbuf_new_from_file_at_size (filename, 128, 128, NULL);
+	g_free (filename);
+	if (!pixbuf)
+		return;
+
+	gtk_file_chooser_set_preview_widget_active (file_chooser, TRUE);
+	gtk_image_set_from_pixbuf (GTK_IMAGE (preview), pixbuf);
+	g_object_unref (pixbuf);
+}
+
 void
 e_attachment_store_run_load_dialog (EAttachmentStore *store,
                                     GtkWindow *parent)
@@ -417,6 +448,7 @@ e_attachment_store_run_load_dialog (EAttachmentStore *store,
 	GtkFileChooser *file_chooser;
 	GtkWidget *dialog;
 	GtkWidget *option;
+	GtkImage *preview;
 	GSList *files, *iter;
 	const gchar *disposition;
 	gboolean active;
@@ -437,6 +469,14 @@ e_attachment_store_run_load_dialog (EAttachmentStore *store,
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "mail-attachment");
 
+	preview = GTK_IMAGE (gtk_image_new ());
+	gtk_file_chooser_set_preview_widget (
+		GTK_FILE_CHOOSER (file_chooser),
+		GTK_WIDGET (preview));
+	g_signal_connect (
+		file_chooser, "update-preview",
+		G_CALLBACK (update_preview_cb), preview);
+
 	option = gtk_check_button_new_with_mnemonic (
 		_("_Suggest automatic display of attachment"));
 	gtk_file_chooser_set_extra_widget (file_chooser, option);
