@@ -943,15 +943,6 @@ em_utils_composer_save_to_outbox_cb (EMsgComposer *composer,
 	camel_message_info_free (info);
 }
 
-static void
-composer_print_done_cb (EMailPrinter *emp,
-                        GtkPrintOperation *operation,
-                        GtkPrintOperationResult result,
-                        gpointer user_data)
-{
-	g_object_unref (emp);
-}
-
 static void
 em_utils_composer_print_cb (EMsgComposer *composer,
                             GtkPrintOperationAction action,
@@ -959,23 +950,21 @@ em_utils_composer_print_cb (EMsgComposer *composer,
                             EActivity *activity,
                             EMailSession *session)
 {
-	EMailPrinter *emp;
 	EMailParser *parser;
 	EMailPartList *parts;
+	EMailPrinter *printer;
 	const gchar *message_id;
 
 	parser = e_mail_parser_new (CAMEL_SESSION (session));
 
 	message_id = camel_mime_message_get_message_id (message);
-	parts = e_mail_parser_parse_sync (parser, NULL, g_strdup (message_id), message, NULL);
+	parts = e_mail_parser_parse_sync (
+		parser, NULL, g_strdup (message_id), message, NULL);
 
-        /* Use EMailPrinter and WebKit to print the message */
-	emp = e_mail_printer_new (parts);
-	g_signal_connect (
-		emp, "done",
-		G_CALLBACK (composer_print_done_cb), NULL);
-
-	e_mail_printer_print (emp, action, NULL, NULL);
+	/* FIXME Show an alert on error. */
+	printer = e_mail_printer_new (parts);
+	e_mail_printer_print (printer, action, NULL, NULL, NULL, NULL);
+	g_object_unref (printer);
 
 	g_object_unref (parts);
 }
@@ -1968,8 +1957,8 @@ em_utils_forward_messages (EMailReader *reader,
 
 static gint
 compare_sources_with_uids_order_cb (gconstpointer a,
-				    gconstpointer b,
-				    gpointer user_data)
+                                    gconstpointer b,
+                                    gpointer user_data)
 {
 	ESource *asource = (ESource *) a;
 	ESource *bsource = (ESource *) b;
@@ -1989,7 +1978,7 @@ compare_sources_with_uids_order_cb (gconstpointer a,
 
 static void
 sort_sources_by_ui (GList **psources,
-		    gpointer user_data)
+                    gpointer user_data)
 {
 	EShell *shell = user_data;
 	EShellBackend *shell_backend;
