@@ -31,10 +31,6 @@
 #include "calendar/gui/e-calendar-selector.h"
 #include "calendar/gui/misc.h"
 
-#include "e-cal-shell-view.h"
-#include "e-cal-shell-backend.h"
-#include "e-cal-shell-content.h"
-
 #define E_CAL_SHELL_SIDEBAR_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), E_TYPE_CAL_SHELL_SIDEBAR, ECalShellSidebarPrivate))
@@ -59,12 +55,12 @@ struct _ECalShellSidebarPrivate {
 	/* Not referenced, only for pointer comparison. */
 	ESource *connecting_default_source_instance;
 
-	GCancellable *connecting_default_client;
-	GCancellable *loading_clients;
+	EActivity *connecting_default_client;
 };
 
 struct _ConnectClosure {
 	ECalShellSidebar *cal_shell_sidebar;
+	EActivity *activity;
 
 	/* For error messages. */
 	gchar *unique_display_name;
@@ -80,7 +76,6 @@ enum {
 enum {
 	CLIENT_ADDED,
 	CLIENT_REMOVED,
-	STATUS_MESSAGE,
 	LAST_SIGNAL
 };
 
@@ -96,25 +91,54 @@ connect_closure_new (ECalShellSidebar *cal_shell_sidebar,
                      ESource *source)
 {
 	ConnectClosure *closure;
+	EAlertSink *alert_sink;
+	GCancellable *cancellable;
 	ESourceRegistry *registry;
 	ESourceSelector *selector;
+	EShellView *shell_view;
+	EShellBackend *shell_backend;
+	EShellContent *shell_content;
+	EShellSidebar *shell_sidebar;
+	gchar *text;
+
+	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
+	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
 	registry = e_source_selector_get_registry (selector);
 
 	closure = g_slice_new0 (ConnectClosure);
 	closure->cal_shell_sidebar = g_object_ref (cal_shell_sidebar);
+	closure->activity = e_activity_new ();
 	closure->unique_display_name =
 		e_source_registry_dup_unique_display_name (
 		registry, source, E_SOURCE_EXTENSION_CALENDAR);
 
+	text = g_strdup_printf (
+		_("Opening calendar '%s'"),
+		closure->unique_display_name);
+	e_activity_set_text (closure->activity, text);
+	g_free (text);
+
+	alert_sink = E_ALERT_SINK (shell_content);
+	e_activity_set_alert_sink (closure->activity, alert_sink);
+
+	cancellable = g_cancellable_new ();
+	e_activity_set_cancellable (closure->activity, cancellable);
+	g_object_unref (cancellable);
+
+	e_shell_backend_add_activity (shell_backend, closure->activity);
+
 	return closure;
 }
 
 static void
 connect_closure_free (ConnectClosure *closure)
 {
-	g_object_unref (closure->cal_shell_sidebar);
+	g_clear_object (&closure->cal_shell_sidebar);
+	g_clear_object (&closure->activity);
 
 	g_free (closure->unique_display_name);
 
@@ -140,28 +164,15 @@ cal_shell_sidebar_emit_client_removed (ECalShellSidebar *cal_shell_sidebar,
 }
 
 static void
-cal_shell_sidebar_emit_status_message (ECalShellSidebar *cal_shell_sidebar,
-                                       const gchar *status_message)
-{
-	guint signal_id = signals[STATUS_MESSAGE];
-
-	g_signal_emit (cal_shell_sidebar, signal_id, 0, status_message);
-}
-
-static void
-cal_shell_sidebar_handle_connect_error (ECalShellSidebar *cal_shell_sidebar,
+cal_shell_sidebar_handle_connect_error (EActivity *activity,
                                         const gchar *unique_display_name,
                                         const GError *error)
 {
-	EShellView *shell_view;
-	EShellContent *shell_content;
-	EShellSidebar *shell_sidebar;
+	EAlertSink *alert_sink;
 	gboolean cancelled = FALSE;
 	gboolean offline_error;
 
-	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
-	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
-	shell_content = e_shell_view_get_shell_content (shell_view);
+	alert_sink = e_activity_get_alert_sink (activity);
 
 	cancelled |= g_error_matches (
 		error, G_IO_ERROR, G_IO_ERROR_CANCELLED);
@@ -171,17 +182,17 @@ cal_shell_sidebar_handle_connect_error (ECalShellSidebar *cal_shell_sidebar,
 	offline_error = g_error_matches (
 		error, E_CLIENT_ERROR, E_CLIENT_ERROR_REPOSITORY_OFFLINE);
 
-	if (cancelled) {
+	if (e_activity_handle_cancellation (activity, error)) {
 		/* do nothing */
 	} else if (offline_error) {
 		e_alert_submit (
-			E_ALERT_SINK (shell_content),
+			alert_sink,
 			"calendar:prompt-no-contents-offline-calendar",
 			unique_display_name,
 			NULL);
 	} else {
 		e_alert_submit (
-			E_ALERT_SINK (shell_content),
+			alert_sink,
 			"calendar:failed-open-calendar",
 			unique_display_name,
 			error->message,
@@ -208,13 +219,15 @@ cal_shell_sidebar_client_connect_cb (GObject *source_object,
 
 	if (error != NULL) {
 		cal_shell_sidebar_handle_connect_error (
-			closure->cal_shell_sidebar,
+			closure->activity,
 			closure->unique_display_name,
 			error);
 		g_error_free (error);
 		goto exit;
 	}
 
+	e_activity_set_state (closure->activity, E_ACTIVITY_COMPLETED);
+
 	e_cal_shell_sidebar_add_client (closure->cal_shell_sidebar, client);
 
 	g_object_unref (client);
@@ -244,20 +257,19 @@ cal_shell_sidebar_default_connect_cb (GObject *source_object,
 		((client != NULL) && (error == NULL)) ||
 		((client == NULL) && (error != NULL)));
 
-	if (priv->connecting_default_client != NULL) {
-		g_object_unref (priv->connecting_default_client);
-		priv->connecting_default_client = NULL;
-	}
+	g_clear_object (&priv->connecting_default_client);
 
 	if (error != NULL) {
 		cal_shell_sidebar_handle_connect_error (
-			closure->cal_shell_sidebar,
+			closure->activity,
 			closure->unique_display_name,
 			error);
 		g_error_free (error);
 		goto exit;
 	}
 
+	e_activity_set_state (closure->activity, E_ACTIVITY_COMPLETED);
+
 	source = e_client_get_source (client);
 
 	if (source == priv->connecting_default_source_instance)
@@ -283,6 +295,7 @@ cal_shell_sidebar_set_default (ECalShellSidebar *cal_shell_sidebar,
 {
 	ECalShellSidebarPrivate *priv;
 	ESourceSelector *selector;
+	ConnectClosure *closure;
 
 	priv = cal_shell_sidebar->priv;
 
@@ -292,22 +305,23 @@ cal_shell_sidebar_set_default (ECalShellSidebar *cal_shell_sidebar,
 	if (source == priv->connecting_default_source_instance)
 		return;
 
-	/* Cancel any unfinished previous request. */
+	/* Cancel the previous request if unfinished. */
 	if (priv->connecting_default_client != NULL) {
-		g_cancellable_cancel (priv->connecting_default_client);
+		e_activity_cancel (priv->connecting_default_client);
 		g_object_unref (priv->connecting_default_client);
 		priv->connecting_default_client = NULL;
 	}
 
+	closure = connect_closure_new (cal_shell_sidebar, source);
+
 	/* it's only for pointer comparison, no need to ref it */
 	priv->connecting_default_source_instance = source;
-	priv->connecting_default_client = g_cancellable_new ();
+	priv->connecting_default_client = g_object_ref (closure->activity);
 
 	e_client_selector_get_client (
 		E_CLIENT_SELECTOR (selector), source,
-		priv->connecting_default_client,
-		cal_shell_sidebar_default_connect_cb,
-		connect_closure_new (cal_shell_sidebar, source));
+		e_activity_get_cancellable (closure->activity),
+		cal_shell_sidebar_default_connect_cb, closure);
 }
 
 static void
@@ -360,27 +374,21 @@ cal_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 {
 	ECalShellSidebarPrivate *priv;
 	EShell *shell;
-	EShellBackend *shell_backend;
 	EShellSettings *shell_settings;
 	ESourceRegistry *registry;
 	ESourceSelector *selector;
 	GSettings *settings;
 	GtkTreeModel *model;
-	GObject *object;
 
 	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
 
 	shell = e_shell_window_get_shell (shell_window);
 	shell_settings = e_shell_get_shell_settings (shell);
 
-	shell_backend = e_shell_view_get_shell_backend (shell_view);
-	g_return_if_fail (E_IS_CAL_SHELL_BACKEND (shell_backend));
-
 	selector = E_SOURCE_SELECTOR (priv->selector);
+	registry = e_source_selector_get_registry (selector);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (selector));
 
-	registry = e_shell_get_registry (shell);
-
 	g_signal_connect_swapped (
 		model, "row-changed",
 		G_CALLBACK (cal_shell_sidebar_row_changed_cb),
@@ -391,6 +399,10 @@ cal_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 		G_CALLBACK (cal_shell_sidebar_primary_selection_changed_cb),
 		shell_sidebar);
 
+	/* Bind GObject properties to settings keys. */
+
+	settings = g_settings_new ("org.gnome.evolution.calendar");
+
 	g_object_bind_property_full (
 		shell_settings, "cal-primary-calendar",
 		selector, "primary-selection",
@@ -401,14 +413,12 @@ cal_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 		g_object_ref (registry),
 		(GDestroyNotify) g_object_unref);
 
-	/* Bind GObject properties to settings keys. */
+	g_settings_bind (
+		settings, "date-navigator-pane-position",
+		priv->paned, "vposition",
+		G_SETTINGS_BIND_DEFAULT);
 
-	settings = g_settings_new ("org.gnome.evolution.calendar");
-
-	object = G_OBJECT (priv->paned);
-	g_settings_bind (settings, "date-navigator-pane-position", object, "vposition", G_SETTINGS_BIND_DEFAULT);
-
-	g_object_unref (G_OBJECT (settings));
+	g_object_unref (settings);
 }
 
 static void
@@ -476,17 +486,11 @@ cal_shell_sidebar_dispose (GObject *object)
 	}
 
 	if (priv->connecting_default_client != NULL) {
-		g_cancellable_cancel (priv->connecting_default_client);
+		e_activity_cancel (priv->connecting_default_client);
 		g_object_unref (priv->connecting_default_client);
 		priv->connecting_default_client = NULL;
 	}
 
-	if (priv->loading_clients != NULL) {
-		g_cancellable_cancel (priv->loading_clients);
-		g_object_unref (priv->loading_clients);
-		priv->loading_clients = NULL;
-	}
-
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (e_cal_shell_sidebar_parent_class)->dispose (object);
 }
@@ -673,8 +677,6 @@ cal_shell_sidebar_client_removed (ECalShellSidebar *cal_shell_sidebar,
 
 	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
 	e_source_selector_unselect_source (selector, source);
-
-	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, NULL);
 }
 
 static void
@@ -744,16 +746,6 @@ e_cal_shell_sidebar_class_init (ECalShellSidebarClass *class)
 		g_cclosure_marshal_VOID__OBJECT,
 		G_TYPE_NONE, 1,
 		E_TYPE_CAL_CLIENT);
-
-	signals[STATUS_MESSAGE] = g_signal_new (
-		"status-message",
-		G_OBJECT_CLASS_TYPE (object_class),
-		G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-		G_STRUCT_OFFSET (ECalShellSidebarClass, status_message),
-		NULL, NULL,
-		g_cclosure_marshal_VOID__STRING,
-		G_TYPE_NONE, 1,
-		G_TYPE_STRING);
 }
 
 static void
@@ -767,8 +759,6 @@ e_cal_shell_sidebar_init (ECalShellSidebar *cal_shell_sidebar)
 	cal_shell_sidebar->priv =
 		E_CAL_SHELL_SIDEBAR_GET_PRIVATE (cal_shell_sidebar);
 
-	cal_shell_sidebar->priv->loading_clients = g_cancellable_new ();
-
 	/* Postpone widget construction until we have a shell view. */
 }
 
@@ -849,33 +839,22 @@ void
 e_cal_shell_sidebar_add_source (ECalShellSidebar *cal_shell_sidebar,
                                 ESource *source)
 {
-	ESourceRegistry *registry;
 	ESourceSelector *selector;
-	gchar *display_name;
-	gchar *message;
+	ConnectClosure *closure;
 
 	g_return_if_fail (E_IS_CAL_SHELL_SIDEBAR (cal_shell_sidebar));
 	g_return_if_fail (E_IS_SOURCE (source));
 
 	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
-	registry = e_source_selector_get_registry (selector);
 
 	e_source_selector_select_source (selector, source);
 
-	display_name = e_source_registry_dup_unique_display_name (
-		registry, source, E_SOURCE_EXTENSION_CALENDAR);
-
-	message = g_strdup_printf (_("Opening calendar '%s'"), display_name);
-	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, message);
-	g_free (message);
-
-	g_free (display_name);
+	closure = connect_closure_new (cal_shell_sidebar, source);
 
 	e_client_selector_get_client (
 		E_CLIENT_SELECTOR (selector), source,
-		cal_shell_sidebar->priv->loading_clients,
-		cal_shell_sidebar_client_connect_cb,
-		connect_closure_new (cal_shell_sidebar, source));
+		e_activity_get_cancellable (closure->activity),
+		cal_shell_sidebar_client_connect_cb, closure);
 }
 
 void
